@@ -163,9 +163,7 @@ void QWebdav::replyReadyRead()
 
 void QWebdav::replyFinished(QNetworkReply* reply)
 {
-#ifdef DEBUG_WEBDAV
-    qDebug() << "QWebdav::replyFinished()";
-#endif
+    qDebug() << "QWebdav::replyFinished() " << reply->rawHeaderList();
 
     disconnect(reply, SIGNAL(readyRead()), this, SLOT(replyReadyRead()));
     disconnect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(replyError(QNetworkReply::NetworkError)));
@@ -184,9 +182,7 @@ void QWebdav::replyFinished(QNetworkReply* reply)
 
 void QWebdav::replyDeleteLater(QNetworkReply* reply)
 {
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::replyDeleteLater()";
-#endif
 
     QIODevice *outDataDevice = m_outDataDevices.value(reply, 0);
     if (outDataDevice!=0)
@@ -200,9 +196,7 @@ void QWebdav::replyError(QNetworkReply::NetworkError)
     if (reply==0)
         return;
 
-#ifdef DEBUG_WEBDAV
-    qDebug() << "QWebdav::replyError()  reply->url() == " << reply->url().toString(QUrl::RemoveUserInfo);
-#endif
+    qWarning() << "QWebdav::replyError()  reply->url() == " << reply->url().toString(QUrl::RemoveUserInfo);
 
     if ( reply->error() == QNetworkReply::OperationCanceledError) {
         QIODevice* dataIO = m_inDataDevices.value(reply, 0);
@@ -218,22 +212,13 @@ void QWebdav::replyError(QNetworkReply::NetworkError)
 
 void QWebdav::provideAuthenication(QNetworkReply *reply, QAuthenticator *authenticator)
 {
-#ifdef DEBUG_WEBDAV
-    qDebug() << "QWebdav::authenticationRequired()";
     QVariantHash opts = authenticator->options();
-    QVariant optVar;
-    foreach(optVar, opts) {
-        qDebug() << "QWebdav::authenticationRequired()  option == " << optVar.toString();
-    }
-#endif
+    qDebug() << "QWebdav::authenticationRequired()  option == " << opts;
 
     if (reply == m_authenticator_lastReply) {
-        reply->abort();
-        emit errorChanged("WebDAV server requires authentication. Check WebDAV share settings!");
-        reply->deleteLater();
-        reply=0;
+        //Avoid endless retries. This will fail with AuthenticationRequiredError
+        return;
     }
-
     m_authenticator_lastReply = reply;
 
     authenticator->setUser(m_username);
@@ -242,9 +227,7 @@ void QWebdav::provideAuthenication(QNetworkReply *reply, QAuthenticator *authent
 
 void QWebdav::sslErrors(QNetworkReply *reply, const QList<QSslError> &errors)
 {
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::sslErrors()   reply->url == " << reply->url().toString(QUrl::RemoveUserInfo);
-#endif
 
     if (m_ignoreSslErrors) {
         // user accepted this SSL certifcate already ==> ignore SSL errors
@@ -258,52 +241,46 @@ QString QWebdav::absolutePath(const QString &relPath)
 
 }
 
-QNetworkReply* QWebdav::createRequest(const QString& method, QNetworkRequest& req, QIODevice* outgoingData)
+QNetworkReply* QWebdav::createDAVRequest(const QString& method, QNetworkRequest& req, QIODevice* outgoingData)
 {
     if(outgoingData != 0 && outgoingData->size() !=0) {
         req.setHeader(QNetworkRequest::ContentLengthHeader, outgoingData->size());
         req.setHeader(QNetworkRequest::ContentTypeHeader, "text/xml; charset=utf-8");
     }
 
-#ifdef DEBUG_WEBDAV
-    qDebug() << " QWebdav::createRequest1";
+    qDebug() << " QWebdav::createDAVRequest1";
     qDebug() << "   " << method << " " << req.url().toString();
     QList<QByteArray> rawHeaderList = req.rawHeaderList();
     QByteArray rawHeaderItem;
     foreach(rawHeaderItem, rawHeaderList) {
         qDebug() << "   " << rawHeaderItem << ": " << req.rawHeader(rawHeaderItem);
     }
-#endif
 
     return sendCustomRequest(req, method.toLatin1(), outgoingData);
 }
 
-QNetworkReply* QWebdav::createRequest(const QString& method, QNetworkRequest& req, const QByteArray& outgoingData )
+QNetworkReply* QWebdav::createDAVRequest(const QString& method, QNetworkRequest& req, const QByteArray& outgoingData )
 {
     QBuffer* dataIO = new QBuffer;
     dataIO->setData(outgoingData);
     dataIO->open(QIODevice::ReadOnly);
 
-#ifdef DEBUG_WEBDAV
-    qDebug() << " QWebdav::createRequest2";
+    qDebug() << " QWebdav::createDAVRequest2";
     qDebug() << "   " << method << " " << req.url().toString();
     QList<QByteArray> rawHeaderList = req.rawHeaderList();
     QByteArray rawHeaderItem;
     foreach(rawHeaderItem, rawHeaderList) {
         qDebug() << "   " << rawHeaderItem << ": " << req.rawHeader(rawHeaderItem);
     }
-#endif
 
-    QNetworkReply* reply = createRequest(method, req, dataIO);
+    QNetworkReply* reply = createDAVRequest(method, req, dataIO);
     m_outDataDevices.insert(reply, dataIO);
     return reply;
 }
 
 QNetworkReply* QWebdav::list(const QString& path)
 {
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::list() path = " << path;
-#endif
     return list(path, 1);
 }
 
@@ -355,7 +332,7 @@ QNetworkReply* QWebdav::search(const QString& path, const QString& q )
 
     req.setUrl(reqUrl);
 
-    return this->createRequest("SEARCH", req, query);
+    return this->createDAVRequest("SEARCH", req, query);
 }
 
 QNetworkReply* QWebdav::get(const QString& path, const QMap<QByteArray, QByteArray> &headers)
@@ -369,9 +346,7 @@ QNetworkReply* QWebdav::get(const QString& path, const QMap<QByteArray, QByteArr
         req.setRawHeader(it.key(), it.value());
     }
 
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::get() url = " << req.url().toString(QUrl::RemoveUserInfo);
-#endif
 
     req.setUrl(reqUrl);
 
@@ -392,9 +367,7 @@ QNetworkReply* QWebdav::get(const QString& path, QIODevice* data, quint64 fromRa
 
     req.setUrl(reqUrl);
 
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::get() url = " << req.url().toString(QUrl::RemoveUserInfo);
-#endif
 
     if (fromRangeInBytes>0) {
         // RFC2616 http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html
@@ -419,9 +392,7 @@ QNetworkReply* QWebdav::put(const QString& path, QIODevice* data)
 
     req.setUrl(reqUrl);
 
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::put() url = " << req.url().toString(QUrl::RemoveUserInfo);
-#endif
 
     return QNetworkAccessManager::put(req, data);
 }
@@ -438,9 +409,7 @@ QNetworkReply* QWebdav::put(const QString& path, const QByteArray& data, const Q
         req.setRawHeader(it.key(), it.value());
     }
 
-#ifdef DEBUG_WEBDAV
     qDebug() << "QWebdav::put() url = " << req.url().toString(QUrl::RemoveUserInfo);
-#endif
 
     return QNetworkAccessManager::put(req, data);
 }
@@ -477,7 +446,7 @@ QNetworkReply* QWebdav::propfind(const QString& path, const QByteArray& query, i
     req.setUrl(reqUrl);
     req.setRawHeader("Depth", depth == 2 ? QString("infinity").toUtf8() : QString::number(depth).toUtf8());
 
-    return createRequest("PROPFIND", req, query);
+    return createDAVRequest("PROPFIND", req, query);
 }
 
 QNetworkReply* QWebdav::report(const QString& path, const QByteArray& query, int depth)
@@ -490,7 +459,7 @@ QNetworkReply* QWebdav::report(const QString& path, const QByteArray& query, int
     req.setUrl(reqUrl);
     req.setRawHeader("Depth", depth == 2 ? QString("infinity").toUtf8() : QString::number(depth).toUtf8());
 
-    return createRequest("REPORT", req, query);
+    return createDAVRequest("REPORT", req, query);
 }
 
 QNetworkReply* QWebdav::proppatch(const QString& path, const QWebdav::PropValues& props)
@@ -531,7 +500,7 @@ QNetworkReply* QWebdav::proppatch(const QString& path, const QByteArray& query)
 
     req.setUrl(reqUrl);
 
-    return createRequest("PROPPATCH", req, query);
+    return createDAVRequest("PROPPATCH", req, query);
 }
 
 QNetworkReply* QWebdav::mkdir (const QString& path)
@@ -543,7 +512,31 @@ QNetworkReply* QWebdav::mkdir (const QString& path)
 
     req.setUrl(reqUrl);
 
-    return createRequest("MKCOL", req);
+    return createDAVRequest("MKCOL", req);
+}
+
+QNetworkReply* QWebdav::mkdir (const QString& path, const QByteArray& query)
+{
+    QNetworkRequest req;
+
+    QUrl reqUrl(m_baseUrl);
+    reqUrl.setPath(absolutePath(path));
+
+    req.setUrl(reqUrl);
+
+    return createDAVRequest("MKCOL", req, query);
+}
+
+QNetworkReply* QWebdav::mkcalendar (const QString& path, const QByteArray& query)
+{
+    QNetworkRequest req;
+
+    QUrl reqUrl(m_baseUrl);
+    reqUrl.setPath(absolutePath(path));
+
+    req.setUrl(reqUrl);
+
+    return createDAVRequest("MKCALENDAR", req, query);
 }
 
 QNetworkReply* QWebdav::copy(const QString& pathFrom, const QString& pathTo, bool overwrite)
@@ -567,7 +560,7 @@ QNetworkReply* QWebdav::copy(const QString& pathFrom, const QString& pathTo, boo
     req.setRawHeader("Depth", "infinity");
     req.setRawHeader("Overwrite", overwrite ? "T" : "F");
 
-    return createRequest("COPY", req);
+    return createDAVRequest("COPY", req);
 }
 
 QNetworkReply* QWebdav::move(const QString& pathFrom, const QString& pathTo, bool overwrite)
@@ -591,7 +584,7 @@ QNetworkReply* QWebdav::move(const QString& pathFrom, const QString& pathTo, boo
     req.setRawHeader("Depth", "infinity");
     req.setRawHeader("Overwrite", overwrite ? "T" : "F");
 
-    return createRequest("MOVE", req);
+    return createDAVRequest("MOVE", req);
 }
 
 QNetworkReply* QWebdav::remove(const QString& path)
@@ -603,5 +596,5 @@ QNetworkReply* QWebdav::remove(const QString& path)
 
     req.setUrl(reqUrl);
 
-    return createRequest("DELETE", req);
+    return createDAVRequest("DELETE", req);
 }
